xsdata.formats.dataclass.models package
=======================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   xsdata.formats.dataclass.models.constants
   xsdata.formats.dataclass.models.elements
   xsdata.formats.dataclass.models.generics

Module contents
---------------

.. automodule:: xsdata.formats.dataclass.models
   :members:
   :undoc-members:
   :show-inheritance:
